@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-''' 
+""" 
 
 Base Scene
 
@@ -8,14 +8,14 @@ Common to all elements returned from rest/nodes/scenes
 
 TBD - may need to change - scene_base and scene_inteon based on insteon only setup
 
-'''
+"""
+
+from ..item_base import Item_Base
 
-from .. item_base import Item_Base
 
 class Scene_Base(Item_Base):
-
     def __init__(self, container, scene_info):
-        Item_Base.__init__(self,container,scene_info.name)
+        Item_Base.__init__(self, container, scene_info.name)
 
         self.address = scene_info.address
         self.flag = scene_info.flag
@@ -30,11 +30,15 @@ class Scene_Base(Item_Base):
         self.responders = scene_info.responders
 
     def __str__(self):
-        return ("Scene: {} ; address {} ; flag {}; id {}".format(self.name, self.address, self.flag, self.id))
+        return "Scene: {} ; address {} ; flag {}; id {}".format(
+            self.name, self.address, self.flag, self.id
+        )
 
-    def device_event(self,device): #device event, process and see if we are interested
-        pass # subclasses to provide
+    def device_event(
+        self, device
+    ):  # device event, process and see if we are interested
+        pass  # subclasses to provide
 
     def get_identifier(self):
-        return self.address       
-        
\ No newline at end of file
+        return self.address
+
